Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3917)

Unified Diff: chrome/browser/chromeos/accessibility/accessibility_util.h

Issue 11415025: A11y: Introduce High Contrast Mode and Screen Magnifier to ubar tray. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: rebase @170134 Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/test/test_shell_delegate.cc ('k') | chrome/browser/chromeos/accessibility/accessibility_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/accessibility/accessibility_util.h
diff --git a/chrome/browser/chromeos/accessibility/accessibility_util.h b/chrome/browser/chromeos/accessibility/accessibility_util.h
index ea5f0217527aeea4f5c0503201c5b704cc0ce985..c264dbc71986accd7ddbdb533733c12936e01f56 100644
--- a/chrome/browser/chromeos/accessibility/accessibility_util.h
+++ b/chrome/browser/chromeos/accessibility/accessibility_util.h
@@ -7,6 +7,10 @@
#include <string>
+#include "ash/magnifier/magnifier_constants.h"
+
+class Browser;
+
namespace content {
class WebUI;
}
@@ -14,30 +18,19 @@ class WebUI;
namespace chromeos {
namespace accessibility {
-// Enable or disable spoken feedback. Enabling spoken feedback installs the
+// Enables or disables spoken feedback. Enabling spoken feedback installs the
// ChromeVox component extension. If this is being called in a login/oobe
// login screen, pass the WebUI object in login_web_ui so that ChromeVox
// can be injected directly into that screen, otherwise it should be NULL.
void EnableSpokenFeedback(bool enabled, content::WebUI* login_web_ui);
-// Enable or disable the high contrast mode for Chrome.
+// Enables or disables the high contrast mode for Chrome.
void EnableHighContrast(bool enabled);
-// String constants of the magnifier types.
-extern const char kScreenMagnifierOff[];
-extern const char kScreenMagnifierFull[];
-extern const char kScreenMagnifierPartial[];
-
-enum ScreenMagnifierType {
- MAGNIFIER_OFF,
- MAGNIFIER_FULL,
- MAGNIFIER_PARTIAL,
-};
+// Sets the type of screen magnifier, or disable it.
+void SetMagnifier(ash::MagnifierType type);
-// Set the type of screen magnifier, or disable it.
-void SetScreenMagnifier(ScreenMagnifierType type);
-
-// Enable or disable the virtual keyboard.
+// Enables or disable the virtual keyboard.
void EnableVirtualKeyboard(bool enabled);
// Toggles whether Chrome OS spoken feedback is on or off. See docs for
@@ -54,17 +47,20 @@ bool IsSpokenFeedbackEnabled();
bool IsHighContrastEnabled();
// Returns the current state of the screen magnifier.
-ScreenMagnifierType GetScreenMagnifierType();
+ash::MagnifierType GetMagnifierType();
-// Translates from a string to ScreenMagnifierType.
-ScreenMagnifierType ScreenMagnifierTypeFromName(const char type_name[]);
+// Translates from a string to MagnifierType.
+ash::MagnifierType MagnifierTypeFromName(const char type_name[]);
-// Translates from a ScreenMagnifierType to type string.
-const char* ScreenMagnifierNameFromType(ScreenMagnifierType type);
+// Translates from a MagnifierType to type string.
+const char* ScreenMagnifierNameFromType(ash::MagnifierType type);
-// Speak the given text if the accessibility pref is already set.
+// Speaks the given text if the accessibility pref is already set.
void MaybeSpeak(const std::string& utterance);
+// Shows the accessibility help tab on the browser.
+void ShowAccessibilityHelp(Browser* browser);
+
} // namespace accessibility
} // namespace chromeos
« no previous file with comments | « ash/test/test_shell_delegate.cc ('k') | chrome/browser/chromeos/accessibility/accessibility_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698